@@ -6,7 +6,7 @@ use utf8;
 package Marlin::Role;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.012001';
+our $VERSION   = '0.013000';
 
 use parent 'Marlin';
 
@@ -64,50 +64,6 @@ sub install_role_tiny {
 	return $me;
 }
 
-sub inject_moose_metadata {
-	my $me = shift;
-	
-	# Recurse to other roles
-	for my $pkg ( @{ $me->roles } ) {
-		Module::Runtime::use_package_optimistically( $pkg->[0] );
-		Marlin->find_meta( $pkg->[0] )->inject_moose_metadata;
-	}
-	
-	require Moose::Util;
-	return if Moose::Util::find_meta( $me->this );
-	
-	require Moose::Meta::Role;
-	my $metarole = Moose::Meta::Role->initialize( $me->this );
-	
-	for my $attr ( @{ $me->attributes } ) {
-		$attr->inject_mooserole_metadata($metarole) or next;
-	}
-	
-	require Moose::Util::TypeConstraints;
-	my $tc = Moose::Util::TypeConstraints::find_or_create_isa_type_constraint( $me->this );
-	$tc->{coercion} = $me->make_type_constraint( $me->this )->coercion->moose_coercion;
-}
-
-sub inject_moo_metadata {
-	my $me = shift;
-	
-	# Recurse to any parents or roles
-	for my $pkg ( @{ $me->parents }, @{ $me->roles } ) {
-		use_package_optimistically( $pkg->[0] );
-		Marlin->find_meta( $pkg->[0] )->inject_moo_metadata;
-	}
-	
-	require Moo::Role;
-	require Method::Generate::Accessor;
-	my $makers = ( $Moo::Role::INFO{$me->this} ||= {} );
-	$makers->{is_role} = 1;
-	$makers->{accessor_maker} = Method::Generate::Accessor->new;
-	
-	for my $attr ( @{ $me->attributes } ) {
-		$attr->inject_moorole_metadata($makers) or next;
-	}
-}
-
 sub _make_modifier_imports {
 	my $me = shift;
 	my $info = $Role::Tiny::INFO{$me->this};
